httpx: The next generation HTTP client.
=======================================

Description
-----------

The next generation HTTP client.

License
-------

Upstream Contact
----------------

https://pypi.org/project/httpx/

